@@ -31,7 +31,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.01_05';
+our $VERSION = '0.03_01';
 
 =head1 NAME
 
@@ -130,12 +130,17 @@ Constants only
 =head1 CONSTANTS
 
 The following constants let AntTweakBar know which graphic system do
-you use.
+you use, to know how to render itself
 
 =head2 TW_OPENGL
 
+Render using plain old OpenGL
+
 =head2 TW_OPENGL_CORE
 
+Render AntTweakBar using OpenGL core profile, which excludes deprecated
+OpenGL functions. See: L<https://en.wikipedia.org/wiki/OpenGL_4#OpenGL_3.2>
+
 =head2 TW_DIRECT3D9 (not implemented)
 
 =head2 TW_DIRECT3D10 (not implemented)
@@ -188,6 +193,16 @@ sub DESTROY {
 }
 
 
+sub _as_definition_string {
+    my $d = shift;
+    return join(' ', map {
+        my $key = $_;
+        my $value = $d->{$key};
+        $value =~ s/'/\\'/g;
+        "$key='$value'";
+    } sort keys %$d);
+}
+
 =head2 add_button
 
   $bar->add_button(
@@ -196,11 +211,21 @@ sub DESTROY {
     definition => "label='Click me!'",    # optional
   );
 
+  $bar->add_button(
+    name       => 'my_btn',
+    cb         => sub { say "clicked!" },
+    definition => { # optional
+      label => 'Click me!'
+    }
+  );
+
+
 The definition parameters are the same as for variable. See
 L<http://anttweakbar.sourceforge.net/doc/tools:anttweakbar:varparamsyntax#parameters>.
 
 =cut
 
+
 sub add_button {
     my ($self, %args) = @_;
 
@@ -212,6 +237,8 @@ sub add_button {
         unless defined $name;
     croak "Button callback should be specified"
         if(!defined($cb) || ref($cb) ne 'CODE');
+    $definition = _as_definition_string($definition)
+        if ($definition && ref($definition) eq 'HASH');
 
     _add_button($self->{_bar_ptr}, $name, $cb, $definition);
 }
@@ -229,6 +256,8 @@ sub add_separator {
         unless defined $name;
 
     $definition //= "";
+    $definition = _as_definition_string($definition)
+        if ($definition && ref($definition) eq 'HASH');
 
     _add_separator($self->{_bar_ptr}, $name, $definition);
 }
@@ -245,6 +274,22 @@ sub add_separator {
     definition => " min=0.01 max=2.5 step=0.01 help='Bla-bla-bla.' ",
   );
 
+  # the same, but with more perlish style in definition
+  $bar->add_variable(
+    mode       => 'rw',
+    name       => "Zoom",
+    type       => 'number',
+    value      => \$zoom,
+    definition => {
+        min     => "0.01",
+        max     => "2.5",
+        step    => "0.01",
+        keyIncr => 'z',
+        keyDecr => 'Z',
+        help    => 'Scale the object (1=original size).'
+    },
+  );
+
   my $bool = undef;
   $bar->add_variable(
     mode       => 'rw',
@@ -322,7 +367,8 @@ If C<cb_write> is undefined, then the variable considered B<readonly>.
 
 =head3 definition
 
-An string that allows additiona tuning of variable.
+An string or hashref of values that allows additional tuning of
+variable in Anttweakbar.
 See L<http://anttweakbar.sourceforge.net/doc/tools:anttweakbar:varparamsyntax#parameters>
 for possible values.
 
@@ -351,6 +397,8 @@ sub add_variable {
     croak "value should be a reference"
         if ($value && !ref($value));
     $type = $type->name if(ref($type) eq 'AntTweakBar::Type');
+    $definition = _as_definition_string($definition)
+        if ($definition && ref($definition) eq 'HASH');
 
     _add_variable($self->{_bar_ptr}, $mode, $name, $type, $value,
                   $cb_read, $cb_write, $definition);
